==> CGAL-4.3-doc_html.tar.xz: doc_html/Surface_mesh_simplification/group__PkgSurfaceMeshSimplification.js <==
var group__PkgSurfaceMeshSimplification =
[
    [ "Concepts", "group__PkgSurfaceMeshSimplificationConcepts.html", "group__PkgSurfaceMeshSimplificationConcepts" ],
    [ "Edge_collapse_visitor_base", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__collapse__visitor__base.html", null ],
    [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html", [
      [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#a38efa1bdb805047165acd873aa253d26", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#ac35825f04d8846aec93db9d5695f720b", null ]
    ] ],
    [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html", [
      [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#a7b1f46cf6f1e1f7c0969f96fb5cb7667", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#ae5828528593c99cf7e17b08b1591b387", null ]
    ] ],
    [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html", [
      [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#a67a62047d79203505a99e6859415ffe5", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#ac786cf1e24bf678456907bd5e60e1e01", null ]
    ] ],
    [ "Edge_profile", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html", null ],
    [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html", [
      [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a747f8fc63c514916ad675404d9d989ca", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a7937e2bc46dfabdfccec4dd019ebded8", null ]
    ] ],
    [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html", [
      [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#abc32f8e2f1fdba289051d75381be0a7b", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a8af3ee3b8ba15d724ed4e7867f01f3c5", null ]
    ] ],
    [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html", [
      [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#ac4edd83862fc95df877fdf781cd10c35", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#ab70b3899cd2cca2275330487ce843dff", null ]
    ] ],
    [ "edge_collapse", "group__PkgSurfaceMeshSimplification.html#ga7f99f1ab3e969b1f0c936896189e4349", null ]
];

==> CGAL-4.10-doc_html.tar.xz: doc_html/Surface_mesh_simplification/group__PkgSurfaceMeshSimplification.js <==
var group__PkgSurfaceMeshSimplification =
[
    [ "Concepts", "group__PkgSurfaceMeshSimplificationConcepts.html", "group__PkgSurfaceMeshSimplificationConcepts" ],
    [ "Edge_collapse_visitor_base", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__collapse__visitor__base.html", null ],
    [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html", [
      [ "Constrained_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Constrained__placement.html#ac6d3aa58c973f3345c84ee6878c22f60", null ]
    ] ],
    [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html", [
      [ "Count_ratio_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#a38efa1bdb805047165acd873aa253d26", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__ratio__stop__predicate.html#ac35825f04d8846aec93db9d5695f720b", null ]
    ] ],
    [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html", [
      [ "Count_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#a7b1f46cf6f1e1f7c0969f96fb5cb7667", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Count__stop__predicate.html#ae5828528593c99cf7e17b08b1591b387", null ]
    ] ],
    [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html", [
      [ "Edge_length_cost", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#a67a62047d79203505a99e6859415ffe5", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__cost.html#a839ac7d4bb0036c8c3325c53246d5a33", null ]
    ] ],
    [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html", [
      [ "Edge_length_stop_predicate", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#a2c4a03a46d8e7b5d4e03cf0c52365464", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__length__stop__predicate.html#a69411bda2f1ec28c64100cb7e1de1369", null ]
    ] ],
    [ "Edge_profile", "classCGAL_1_1Surface__mesh__simplification_1_1Edge__profile.html", null ],
    [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html", [
      [ "LindstromTurk_cost", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#a747f8fc63c514916ad675404d9d989ca", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__cost.html#ab7d145d03f76a39c77eb86535906912b", null ]
    ] ],
    [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html", [
      [ "LindstromTurk_placement", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#abc32f8e2f1fdba289051d75381be0a7b", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1LindstromTurk__placement.html#a501ecd1a41a525288310fe424af59ea4", null ]
    ] ],
    [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html", [
      [ "Midpoint_placement", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#ac4edd83862fc95df877fdf781cd10c35", null ],
      [ "operator()", "classCGAL_1_1Surface__mesh__simplification_1_1Midpoint__placement.html#af61b8d3a9b41c0046a212e3729726dca", null ]
    ] ],
    [ "edge_collapse", "group__PkgSurfaceMeshSimplification.html#gaa2ee2366bf682576542bab5a7e47d597", null ]
];
